@@ -29,7 +29,7 @@
 #else
 #define DICTDIR         "/dict"
 #ifndef DEFAULTPATH
-#define DEFAULTPATH	"/usr/local/share/wordnet/dict"
+#define DEFAULTPATH	"%LOCALBASE%/share/wordnet/dict"
 #endif
 #define DATAFILE	"%s/data.%s"
 #define INDEXFILE	"%s/index.%s"
